@@ -1,4 +1,4 @@
-#define QT_FEATURE_accessibility_atspi_bridge 1
+#define QT_FEATURE_accessibility_atspi_bridge -1
 
 #define QT_FEATURE_directfb -1
 
@@ -14,7 +14,7 @@
 
 #define QT_FEATURE_emojisegmenter 1
 
-#define QT_FEATURE_evdev 1
+#define QT_FEATURE_evdev -1
 
 #define QT_FEATURE_vxworksevdev -1
 
@@ -50,13 +50,13 @@
 
 #define QT_FEATURE_vnc 1
 
-#define QT_FEATURE_mtdev 1
+#define QT_FEATURE_mtdev -1
 
 #define QT_FEATURE_vkgen 1
 
-#define QT_FEATURE_vkkhrdisplay 1
+#define QT_FEATURE_vkkhrdisplay -1
 
-#define QT_FEATURE_egl_x11 1
+#define QT_FEATURE_egl_x11 -1
 
 #define QT_FEATURE_eglfs -1
 
@@ -98,9 +98,9 @@
 
 #define QT_FEATURE_tuiotouch 1
 
-#define QT_FEATURE_xcb_glx 1
+#define QT_FEATURE_xcb_glx -1
 
-#define QT_FEATURE_xcb_egl_plugin 1
+#define QT_FEATURE_xcb_egl_plugin -1
 
 #define QT_FEATURE_xcb_native_painting -1
 
@@ -128,5 +128,5 @@
 
 #define QT_FEATURE_graphicsframecapture -1
 
-#define QT_FEATURE_run_opengl_tests 1
+#define QT_FEATURE_run_opengl_tests -1
 
